d-core.core.messaging.dead-letter

Dead letter support (public facade).

This namespace is intentionally small and stable:

  • It provides the public API (DeadLetterProtocol, send-dead-letter!, helpers)
  • It requires all built-in sink implementations so Integrant can resolve their keys

Protocol

  • d-core.core.messaging.dead-letter.protocol

Built-in implementations

  • Logger sink: d-core.core.messaging.dead-letter.sinks.logger
  • Storage sink: d-core.core.messaging.dead-letter.sinks.storage
  • Producer sink: d-core.core.messaging.dead-letter.sinks.producer
  • Common facade (sink selection/fallback): d-core.core.messaging.dead-letter.common

Extending

Add a new sink under d-core.core.messaging.dead-letter.sinks.* and implement DeadLetterProtocol. If you want it to be wired via Integrant, define a (defmethod ig/init-key ...) in that namespace and ensure it gets required (either by requiring this facade, or by requiring your sink namespace directly).

Dead letter support (public facade).

This namespace is intentionally small and stable:
- It provides the public API (`DeadLetterProtocol`, `send-dead-letter!`, helpers)
- It *requires* all built-in sink implementations so Integrant can resolve their keys

## Protocol
- `d-core.core.messaging.dead-letter.protocol`

## Built-in implementations
- Logger sink: `d-core.core.messaging.dead-letter.sinks.logger`
- Storage sink: `d-core.core.messaging.dead-letter.sinks.storage`
- Producer sink: `d-core.core.messaging.dead-letter.sinks.producer`
- Common facade (sink selection/fallback): `d-core.core.messaging.dead-letter.common`

## Extending
Add a new sink under `d-core.core.messaging.dead-letter.sinks.*` and implement
`DeadLetterProtocol`. If you want it to be wired via Integrant, define a
`(defmethod ig/init-key ...)` in that namespace and ensure it gets required
(either by requiring this facade, or by requiring your sink namespace directly).
raw docstring

DeadLetterProtocolcljprotocol


normalize-error-infoclj


send-dead-letter!clj

cljdoc builds & hosts documentation for Clojure/Script libraries