d-core.queue


dequeueclj


dequeue!clj

(dequeue! queue)

Removes and returns the next item from the queue, or nil when empty.

Removes and returns the next item from the queue, or nil when empty.
raw docstring

enqueueclj


enqueue!clj

(enqueue! queue item)

get-or-create-queue!clj

(get-or-create-queue! queues topic)

Returns the queue atom for topic, creating it if missing.

Returns the queue atom for `topic`, creating it if missing.
raw docstring

get-queueclj

(get-queue queues topic)

get-queue!clj

(get-queue! queues topic)

known-topicsclj

(known-topics queues)

peekclj

(peek queue)

Returns the next item without removing it, or nil when empty.

Returns the next item without removing it, or nil when empty.
raw docstring

sizeclj

(size queue)

cljdoc builds & hosts documentation for Clojure/Script libraries