Dead-letter policy: classification + destination selection.
Policies decide:
The effective per-topic configuration is expected to be present on the envelope at:
[:metadata :dlq :deadletter]
(populated by consumer runtimes).Dead-letter policy: classification + destination selection. Policies decide: - whether a dead-letter is eligible for auto replay vs stuck/poison/manual - which sink to use (logger/storage/producer/hybrid) - which destination to publish to (e.g. retry vs stuck DLQ topics) - limits like :max-attempts / :delay-ms The effective per-topic configuration is expected to be present on the envelope at: - `[:metadata :dlq :deadletter]` (populated by consumer runtimes).
(classify this envelope error-info opts)Return a decision map.
Must return:
:status keyword:sink keywordMay return:
:max-attempts int:delay-ms intReturn a decision map. Must return: - `:status` keyword - `:sink` keyword May return: - `:max-attempts` int - `:delay-ms` int
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |