(dequeue! queue)Removes and returns the next item from the queue, or nil when empty.
Removes and returns the next item from the queue, or nil when empty.
(enqueue! queue item)(get-or-create-queue! queues topic)Returns the queue atom for topic, creating it if missing.
Returns the queue atom for `topic`, creating it if missing.
(get-queue queues topic)(get-queue! queues topic)(known-topics queues)(peek queue)Returns the next item without removing it, or nil when empty.
Returns the next item without removing it, or nil when empty.
(size queue)cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |